Module io

Module io 

Core implementation for I/O operations.

The central traits are Read and Write.

Reimplementation of std::io.

Structs

Buffer
A wrapper around an in-memory slice of bytes.
Counter
A sink that counts the number of bytes written through both fmt::Write and io::Write.
Cursor
A moving cursor over a slice of bytes.
IoFmt
An adapter from io::Write to fmt::Write.

Enums

Error
An error yielded from an I/O operation.

Traits

Read
A source for reading binary data.
Seek
A reader or writer that can be moved to an arbitrary position.
Write
A sink for binary data.

Functions

copy
Copy bytes from reader to writer until reader is exhausted (returns None).
to_io
Convert an std::io::ErrorKind to an Error.

Type Aliases

ReadResult
The result of a read operation.
Result
A specialized Result alias for I/O operations.