Structs
- Buffer
- A wrapper around an in-memory slice of bytes.
- Counter
- A sink that counts the number of bytes written through both
fmt::Writeandio::Write. - Cursor
- A moving cursor over a slice of bytes.
- IoFmt
- An adapter from
io::Writetofmt::Write.
Enums
- Error
- An error yielded from an I/O operation.
Traits
- Read
- A source for reading binary data.
- Seek
- A reader or writer that can be moved to an arbitrary position.
- Write
- A sink for binary data.
Functions
- copy
- Copy bytes from
readertowriteruntilreaderis exhausted (returnsNone). - to_io
- Convert an
std::io::ErrorKindto anError.
Type Aliases
- Read
Result - The result of a read operation.
- Result
- A specialized Result alias for I/O operations.